/* 
 * CSE142, 99 Winter
 * Homework 5
 * Valentine's Day
 *
 * Author:     Doug Thompson
 * Student ID: 9834830
 * Section:    AE
 *	
 *  FINAL PROGRAM
 *
 */

#include "gp142.h"
#include <math.h>
#include <time.h>

#define TRUE    		1
#define FALSE   		0


#define STATUS_ADD_SHAPE 1
#define STATUS_SELECTED 2
#define STATUS_ADD_MESSAGE 3
#define STATUS_CLICK_OBJECT 4

/* Configure the appearance of the buttons on the menu bar 
 * by setting the number of pixels of button height and width
 */
#define BUTTON_HEIGHT  	40
#define BUTTON_WIDTH 	110

#define NUM_BUTTONS 	7
#define SELECTED_COLOR  PURPLE

/* Position of the card in the window */
#define PAGE_LLX (-GP142_XMAX + BUTTON_WIDTH +60)
#define PAGE_LLY (-GP142_YMAX + 100)
#define PAGE_WIDTH (GP142_XMAX - PAGE_LLX - 80)
#define PAGE_HEIGHT (GP142_YMAX - PAGE_LLY - 50)

#define FILL 0
#define NOFILL 1

/* Types of objects we support.*/
#define OBJECT_NONE 0
#define OBJECT_SHAPE 1
#define OBJECT_MESSAGE 2

#define MAX_SHAPES 5
#define MAX_MESSAGES 5
#define FIRST_SHAPE_NUM 0
#define MAX_OBJECTS 100

#define SHAPE_HEART  0
#define SHAPE_FACE   1
#define SHAPE_BODY   2
#define SHAPE_STAR   3
#define SHAPE_ARROW  4

/*Possible places for mouse clicks*/
#define CLICK_BUTTON 1  /* You clicked on SOME button (doesn't say which one)*/
#define CLICK_CARD 2    /* You clicked in the card area */
#define CLICK_OUTSIDE 3	/* You clicked outside the card area, not on a button*/	


/*******************  FUNCTION PROTOTYPES **************************/

/* Drawing functions */
void DrawBlankScreen (void);
void DrawBorder(void);
void DrawButtons(int last_button);
void DrawCard (int background_color, int status, int select, int object_count, 
			   int type[], int number[], 
			   int color[], int x_cor[], int y_cor[]);
void DrawTitle(void);
void DrawShape(int color, int shape_type, int bottom_x, int bottom_y, int background_color);
void DrawMessage(int shape_type, int color, int bottom_x, int bottom_y);
void DrawHeart (int x, int y, int color);
void DrawStar (int x, int y, int color);
void DrawArrow (int x, int y, int color);
void DrawFace (int x, int y, int color);
void DrawBody (int x1, int y1, int color, int background_color);
void DrawChecker(int *color);


/* Mouse click handling functions */
void HandleMouseClick(int mouse_x, int mouse_y, int *background_color, 
					  int *status, int *select, int *highlight, int *object_count,
					  int *object_position, int type[], 
					  int number[], int color[], 
					  int x_cor[], int y_cor[]);
int ClassifyMouseClick(int mouse_x, int mouse_y);
void HandleButton(int x, int y, int *background_color, int *status, int *select,
				  int *highlight, int *object_count,
				  int *object_position, int type[], int number[], int color[],
				  int x_cor[], int y_cor[]);

/* Add a shape to the card. */
void AddShape(int x, int y, int *status, int *select, int *object_count, int *object_position, 
			   int *object_type, int *object_num, int *object_color, 
			   int *object_x, int *object_y);
/* Add a message to the card. */
void AddMessage(int x, int y, int *status, int *select, int *object_count, int *object_position, 
			    int type[], int number[], int color[], 
			    int x_cor[], int y_cor[]);
void ChangeObject(int x, int y, int *status, int *select, int *object_count, int *object_position,
			    int type[], int number[], int color[], int x_cor[], int y_cor[]);

/*****************************************************************************

     MAIN

*****************************************************************************/

int main(void)
{
	int quit = FALSE;              /* becomes TRUE to exit program */
	int mouse_x, mouse_y;          /* coordinates of a mouse click */
	char key_hit;                  /* which key was hit            */
	
	
	/*variables and their default values*/
	int background_color = YELLOW;
	int status = STATUS_ADD_SHAPE;
	int select = 0;
    

	int object_count = 0;           /* How many objects on the page?                */
	int object_position = 0;        /* object number that is selected               */ 
	int object_type = OBJECT_NONE;  /* Can also be a shape                          */
	int last_button = -1;           /* Keep track of the last button clicked.       */
	int highlight = 0;              /* This would be usefull when highlighting      */
	                                /* the last button the user clicked             */

	int event; /*the most recent GP142 event*/
	int	  type[MAX_OBJECTS];      /* this will track if the object is a shape or message */
	int	number[MAX_OBJECTS];      /* corresponds to object_num */
	int  color[MAX_OBJECTS];      /* object_color              */
	int  x_cor[MAX_OBJECTS];      /* object_x                  */
	int  y_cor[MAX_OBJECTS];      /* object_y                  */
	
	int i;

	time_t t; /*needed only when initializing a random number generator*/
	

	/*
	 * INITIALIZATIONS
	 */
	srand (time(&t));	    /* Seed the random number generator. This is 
							   something you should do if you plan to use 
							   random numbers. Leave it here in your program 
							   and forget about it.*/
	

	/* These GP142 initializations don't need to be changed */
	GP142_open();           /* Open and init the GP142 Graphics Window      */
	GP142_show_text(0);     /* Hide the text window                         */
	GP142_logging(LOG_OFF); /* Change to LOG_ON if you want it.             */
	
	GP142_clear();	        /* This will clear the window & paint it white. */
	GP142_animate(ANI_RUN); /* Enable periodic events                       */
	

	for (i=0; i<=20; i++)   /* initialize all array values to 0             */ 
		{
			number[i] = 0;
			color[i] = RED;
		}


	/*
	 * The main event loop:
	 * --- ---- ----- -----
	 * wait for the next user action, such as a mouse click or keyboard
	 * keypress, or a periodic update event (allowing us to display the
	 * next frame of an animation -- not used directly in this program)
	 * and call the appropriate function to handle it.  Repeat this until 
	 * the user signals "quit".
	 */
	while (!quit) {  /*this is the famous "event loop" */
		
		/*start by redrawing everything */
		DrawBlankScreen ();
		DrawChecker(&background_color);
		DrawBorder();   /* draws black border around card */                
		DrawCard (background_color, status, select, object_count,
			      type, number, color, 
				  x_cor, y_cor);
	
	
		if (object_count == 0)
			highlight = 7;

		DrawButtons(highlight);	  /* Show the buttons...*/ 
		
		/*Wait for something to happen */
		event = GP142_await_event(&mouse_x, &mouse_y, &key_hit);
		
		/* Something just happened.  Figure out what it was, and react 
		   appropriately. */
		switch (event) {
		case GP142_QUIT:
			quit = TRUE;           /* set flag to terminate loop           */
			break;
			
		case GP142_KBD:  /*A key was pressed */
			/*not needed for this program. Use this if user will need to 
			  hit a key. Note that scanf CANNOT be used with GP142.  If you 
			  use this, the key character value is in variable "key_hit"*/
			break;
			
		case GP142_MOUSE:
			/* A mouse click has occurred. Call the mouse handler to 
			   decide where the click was and react as needed. */
			HandleMouseClick(mouse_x, mouse_y, &background_color, &status, &select, 
							 &highlight, &object_count, &object_position, type, 
							 number, color, x_cor, y_cor);						

			break;
			
		case GP142_PERIODIC:
			/*An events has occurred simply because some time has passed,*/
			/*not currently used in the program*/		
			break;

		default:
			
			break;
			
		}  /*end switch */
		
	}  /* end event loop */
	
	
	/*
	 * WRAP-UP
	 */
	GP142_close();         /* clean up and close graphics window   */
	
	return 0;
}  /*end main */

/*****************************************************************************

     FUNCTIONS

*****************************************************************************/
/* 
 * For a blank screen just draw a white rectangle that covers the whole
 * GP142 window.
 */
void DrawBlankScreen (void) {
	int font_size = 14;

	GP142_rectangleXY (WHITE,
					-GP142_XMAX, -GP142_YMAX,
					GP142_XMAX, GP142_YMAX,
					FILL);

} /*end DrawBlankScreen */


/* 
 * Draws the buttons 
 */
void DrawButtons(int last_button)
{

	char b_labels [NUM_BUTTONS][30] = {
		"Background color",
			"Object color",
			"Next, please",
			"Add message",
			"Add shape",
			"Select object \nto change",
			"Clear dat!"
	};
	
	int i, text_offset = -GP142_XMAX + 6, font_size = 12;
	int y, label_y;
	
	/* draw rectangles and labels for each button */
	for(i = 0; i < NUM_BUTTONS; i++) {
		y = GP142_YMAX - i * BUTTON_HEIGHT;
		
		GP142_rectangleXY(BLUE,
			-GP142_XMAX + 4,
			y - 2,
			-GP142_XMAX + BUTTON_WIDTH,
			y - BUTTON_HEIGHT - 2, 1);
		
		
		label_y = y - BUTTON_HEIGHT/2;
		
		if (i == last_button)
			{if (i == 0)
				GP142_printfXY(SELECTED_COLOR, text_offset, label_y, 
						       font_size + 6, "Background \ncolor");
			else GP142_printfXY(SELECTED_COLOR, text_offset, label_y,
				                font_size + 6, b_labels[i]);	
			}
		else
			GP142_printfXY(BLUE, text_offset, label_y, font_size + 3,
			               b_labels[i]);	
	}	
}


/*
 * Render (draw) the page and all its contents.
 */
void DrawCard (int background_color, int status, int select, int object_count,
			   int type[], int number[], int color[], int x_cor[], int y_cor[])
{
	int font_size = 14;
	int i;
	/*
	 * Draw the background of the card.
	 */
	GP142_rectangleXY (background_color,
		PAGE_LLX, PAGE_LLY,
		PAGE_LLX+ PAGE_WIDTH, PAGE_LLY+ PAGE_HEIGHT,
		FILL);
	
	DrawTitle();

	/* 
	 * Redraw all objects previously chosen utilizing their arrays
	 */
		 for (i=0; i <= object_count; i++)
		 {	 if (type[i] == OBJECT_SHAPE)
				DrawShape(number[i], color[i], x_cor[i], y_cor[i], background_color);
			 else if (type[i] == OBJECT_MESSAGE)
				DrawMessage(number[i], color[i], x_cor[i], y_cor[i]);
		 }


	
	/*
	 * Write an appropriate status message below the background
	 */
	switch (status) {
	case STATUS_ADD_SHAPE:
		GP142_printfXY (PURPLE, PAGE_LLX, PAGE_LLY-40, font_size + 6,
			"Click on the card to add a shape");
		break;
	case STATUS_SELECTED:
		GP142_printfXY (FOREST_GREEN, PAGE_LLX-20, PAGE_LLY-40, font_size,
			"Object selected. Click on the card to move it, or click 'color' or 'next' buttons");
		break;
	case STATUS_ADD_MESSAGE:
		GP142_printfXY (BLUE, PAGE_LLX, PAGE_LLY-40, font_size + 6, 
			"Click on the card to add message");
		break;
	case STATUS_CLICK_OBJECT:
		GP142_printfXY (RED, PAGE_LLX, PAGE_LLY-40, font_size + 6, 
			"To select an object to change:");
		GP142_printfXY (OLIVE, PAGE_LLX, PAGE_LLY-60, font_size + 6, 
			"Click the shape near its orgin");
		GP142_printfXY (OLIVE, PAGE_LLX, PAGE_LLY-80, font_size + 6, 
			"Click the message at the bottom, left corner");
		break;
	default:
		GP142_printfXY (BLACK, PAGE_LLX, PAGE_LLY-40, font_size,
			"Status error -- notify programmer");
		break;
	} /*end switch */
	
	
} /*end DrawPage */


/*
 * Draw one shape.
 */
void DrawShape(int shape_type, int color, int bottom_x, int bottom_y, 
			   int background_color) {

	switch ((shape_type - FIRST_SHAPE_NUM) % MAX_SHAPES) {
	case SHAPE_HEART:
		DrawHeart (bottom_x, bottom_y, color);
		break;
	case SHAPE_FACE:
		DrawFace (bottom_x, bottom_y, color);
		break;
	case SHAPE_BODY:
		DrawBody (bottom_x, bottom_y, color, background_color);
		break;
	case SHAPE_STAR:
		DrawStar (bottom_x, bottom_y, color);
		break;
	case SHAPE_ARROW:
		DrawArrow(bottom_x, bottom_y, color);
		break;
	default:

		/* Unknown shape selected */
		break;

	} /*end switch*/

}


/* Draw a message on the card.                                   */

void DrawMessage(int shape_type, int color, int bottom_x, int bottom_y) 
{
	int	font = (16 + (rand() % 4));

	switch ((shape_type) % MAX_MESSAGES)
	{
	case 0:
		GP142_printfXY(color, bottom_x, bottom_y, font, 
				       "Happy Valentine's Day");
		break;
	case 1:
		GP142_printfXY(color, bottom_x, bottom_y, font,
			           "Lovin' you");
		break;
	case 2:
		GP142_printfXY(color, bottom_x, bottom_y, font,
			           "...so tell me, who created this day?");
		break;
	case 3:
		GP142_printfXY(color, bottom_x, bottom_y, font, "Got Milk?");
		break;
	case 4:
		GP142_printfXY(color, bottom_x, bottom_y, font, "Roses, what roses?");
		break;
	default:
		break;
	}
}
/*
 * Draw a heart on the card. A heart will be made by two overlapping
 * circles and a triangle.
 *
 * The pulsation is caused by adding a small, random amount to the 
 * heart height each time this function is called.
 */
#define HEART_WIDTH 35
void DrawHeart (int x, int y, int color) {

	int h = (HEART_WIDTH/2) + (rand () %4);

	GP142_circleXY   (color, x - h + 5, y, h);
	GP142_circleXY   (color, x + h - 5, y, h);
	GP142_triangleXY (color, x- h*2 +5, y-5,
						x + h*2 -5, y-5,
						x, y - h*2 -5, FILL);

}




/*
 * Draw a star on the card.
 *
 * We make the star twinkle by selecting the number of points randomly.  Each 
 * time it is redrawn, it is slightly different than the time before, which 
 * makes it appear to pulsate,
 */
#define STARPOINTS 5
#define STARRADIUS 40
#define PI 3.1416
void DrawStar (int x, int y, int color) {

	int sp;
	double angle;
	int x1, y1;

	sp = STARPOINTS + (rand () %3);
	for (angle = 0.0; angle < 2 * PI; angle = angle + (2*PI)/sp) {
		x1 = (int) (cos (angle) * STARRADIUS);
		y1 = (int) (sin (angle) * STARRADIUS);
		GP142_lineXY (color, x+x1, y+y1, x-x1, y-y1, 1);

	}
}


/*
 * Mouse clicks occur in one of three regions of interest: on buttons, 
 * on the card, or anywhere else.
 */
int  ClassifyMouseClick(int mouse_x, int mouse_y)
{
  if ((mouse_x < -GP142_XMAX + BUTTON_WIDTH) &&
      (mouse_y < GP142_YMAX) &&
      (mouse_y > (GP142_YMAX - NUM_BUTTONS*BUTTON_HEIGHT)))
    return CLICK_BUTTON;
  else if (mouse_x >= PAGE_LLX && mouse_x < PAGE_LLX + PAGE_WIDTH
	  && mouse_y >= PAGE_LLY && mouse_y < PAGE_LLY + PAGE_HEIGHT)
    return CLICK_CARD;
  else
    return CLICK_OUTSIDE;

}


/*
 * Decide where a mouse click occured, and react appropriately.
 */
void HandleMouseClick(int mouse_x, int mouse_y, int *background_color, 
					  int *status, int *select, int *highlight, 
					  int *object_count, int *object_position, int type[], 
					  int number[], int color[], 
					  int x_cor[], int y_cor[])   
{

	int mouse_click;
	mouse_click = ClassifyMouseClick(mouse_x, mouse_y);
			
	if (mouse_click == CLICK_BUTTON)
	{
		/* A button has been clicked.  Call a function to handle it*/
		/* most of the variables passed as args will NOT change*/
		
		HandleButton(mouse_x, mouse_y, background_color, status, select,
			         highlight, object_count, object_position, type,
					 number, color, x_cor, y_cor);    
	}
	else if (mouse_click == CLICK_CARD) 
	{
		/* Add a shape, if there isn't one already */
		switch(*select)
		{
			case 0:
				if  (*object_count == 0) 
					AddShape(mouse_x, mouse_y, status, select, object_count,
					         object_position, type, number, color, x_cor, y_cor);
				else if (type[*object_position] == OBJECT_SHAPE)
					AddShape(mouse_x, mouse_y, status, select, object_count, 
					         object_position, type, number, color, x_cor, y_cor);
				else if (type[*object_position] == OBJECT_MESSAGE)
					AddMessage(mouse_x, mouse_y, status, select, object_count,
					object_position, type, number, color, x_cor, y_cor);
				break;
			case 1:
				ChangeObject(mouse_x, mouse_y, status, select, object_count, 
					         object_position, type, number, color, x_cor, y_cor);	
				break;
			default:
				break;
		}
	}
}

/* 
 * Figure out which button was clicked, if any, and do the right 
 * thing.
 */
void HandleButton(int x, int y, int *background_color, int *status,
				  int *select, int *highlight, int *object_count,
				  int *object_position, int type[], int number[], int color[],
				  int x_cor[], int y_cor[])                          
{
	int buttonNum = 0;
	int i;
	
	/* If we're outside of this area, we could not have clicked on
	* a button.
	*/
	if (x > -GP142_XMAX + BUTTON_WIDTH)  
		return ;	/*That's an error situation*/
	

	buttonNum = (GP142_YMAX - y)/BUTTON_HEIGHT;	 
	
	switch(buttonNum) {
	case 0:
		/* Change the background color */
		*background_color = (*background_color + 1) % MAX_COLORS;
		*highlight = 0;
		break;
	case 1:
		/* case 1 needs to be filled with object color */
		color[*object_position] = (color[*object_position] + 1) % MAX_COLORS;   
		*highlight = 1;
		break;
	case 2: 
		/* Change the type of the currently selected object */
		if (type[*object_position] == OBJECT_SHAPE)
			number[*object_position] = (number[*object_position] + 1) % MAX_SHAPES;
		else if (type[*object_position] == OBJECT_MESSAGE)
			number[*object_position] = (number[*object_position] + 1) % MAX_MESSAGES;
		*highlight = 2;
		break;
	case 3:
		/* Add a message to the card, defaulted to "Happy Valentine's Day" */
		{
			*object_count = *object_count + 1;
			*object_position = *object_count;
			*status = STATUS_ADD_MESSAGE;
			type[*object_position] = OBJECT_MESSAGE;
		}
		*highlight = 3;
		break;
	case 4:
		/* If user clicks on the Add Shape button, and then click on the card, a new
		   shape will appear.                                                       	*/
		{
			*object_count = *object_count + 1;
	   		*object_position = *object_count;
			*status = STATUS_ADD_SHAPE;
			type[*object_position] = 1;
		}
		*highlight = 4;
		break;
	case 5:
		/* Selects an object that has already been put on the card, and 
		   allows the user to change its color, rotate through its possible
		   shapes or messages, and allows the user to move it.  The array 
		   that contains this information isn't shifted, rather the function
		   ChangeObject locates the mouse click and determines if it is close 
		   to the orgin of the object.  If an object is selected, its single 
		   position in the array is the only thing manipulated.  Tricky. */
		   
		{	
			*select = 1;
			*status = STATUS_CLICK_OBJECT;
		}
		*highlight = 5;
		break;
	case 6: 
		/* Clear the card and start over.  Re-initialize the array values   */

    	for (i=0; i<=20; i++)   /* initialize all array values to 0         */ 
		{
			number[i] = 0;
			color[i] = RED;
			x_cor[i] = 1000000;  /* out of bounds */
			y_cor[i] = 1000000;
			type[i]= OBJECT_NONE;  /* Can also be a shape           */
		}
		*object_count = 0;
		*object_position = 0;
		*status = STATUS_ADD_SHAPE;
		*highlight = 6;
		GP142_clear();
		
		break;
	default:
		*status = 999;
		/*Bad news if this is ever reached! */
		break;
	}
}


/* If there's room for another shape, add it to the card. */
void AddShape(int x, int y, int *status, int *select, int *object_count,
			  int *object_position, int type[], int number[], int color[], 
			   int x_cor[], int y_cor[])
{
		*status = STATUS_SELECTED;
		type[*object_position] = OBJECT_SHAPE;
		x_cor[*object_position] = x;
		y_cor[*object_position] = y;
}


/* Add message to the card */
void AddMessage(int x, int y, int *status, int *select, int *object_count, 
				int *object_position, int type[], int number[], int color[], 
			    int x_cor[], int y_cor[])
{
		*status = STATUS_SELECTED;
		type[*object_position] = OBJECT_MESSAGE;
		x_cor[*object_position] = x;
		y_cor[*object_position] = y;
}


/* This function is supposed to select an object if the mouse has clicked close
   to its origin.  When the "select object" button is pushed, the user can then click on 
   the card as many times as they wish trying to locate the origin of an object.
   The position in the array that that object holds is then able to be manipulated    */

void ChangeObject(int x, int y, int *status, int *select, int *object_count, 
				  int *object_position, int type[], int number[], int color[],
				  int x_cor[], int y_cor[])
{
	int i;
	
	for (i = 0; i <= *object_count; i++)
	{
		if (((x_cor[i] - 10) <= x) && ((x_cor[i] + 10) >= x))
			if (((y_cor[i] - 10) <= y) && ((y_cor[i] + 10) >= y))
			{
				*object_position = i;
				*select = 0;
			}
	}
}


/* Draw an arrow with a heart at its point.  The length of the arrow 
   changes, but the heart does not  */

void DrawArrow(int x, int y, int color)
{
	int r, h;
	
	h = 10;
	r = (10 + rand () % 6);

		/* arrow fins  */
	GP142_lineXY(FOREST_GREEN, x + (6 + r * 8),      y, x + (6 + r * 8) + 10, y + (2 + r), 1);
	GP142_lineXY(FOREST_GREEN, x + (6 + r * 8) - 5,  y, x + (6 + r * 8) + 5,  y + (2 + r), 1);
	GP142_lineXY(FOREST_GREEN, x + (6 + r * 8) - 10, y, x + (6 + r * 8),      y + (2 + r), 1);
	GP142_lineXY(FOREST_GREEN, x + (6 + r * 8),      y, x + (6 + r * 8) + 10, y - (2 + r), 1);
	GP142_lineXY(FOREST_GREEN, x + (6 + r * 8) - 5,  y, x + (6 + r * 8) + 5,  y - (2 + r), 1);
	GP142_lineXY(FOREST_GREEN, x + (6 + r * 8) - 10, y, x + (6 + r * 8),      y - (2 + r), 1);


	GP142_lineXY(BROWN, x, y, x + (6+ r * 8), y, 5);  /* arrow */
	GP142_circleXY(color, x, y - h + 5, h);			  /* heart point */
	GP142_circleXY(color, x, y + h - 5, h);
	GP142_triangleXY(color, x - 5, y - (h * 2) + 5,
					 x - 5, y + (h * 2) - 5,
					 x - (h * 2) - 5, y, FILL);
	


}

/* Draw a smily face.  */

#define FACE_WIDTH 60
#define VERTICES 15

void DrawFace(int x, int y, int color)
{
	int	h = x + (rand() % 6);
	int v = y + (rand() % 6);
	int eye = (rand() % 4);
	int blink = (rand() % 10);
	int smile;

	
	GP142_circleXY(BLACK, h, v, 32);  /* black outline */
  	GP142_circleXY(color + 5, h, v, 30);  /* head          */
	if (blink < 8)
	{
		GP142_circleXY(WHITE, h - 8, v + 4, 5);  /* eyes */
		GP142_circleXY(WHITE, h + 8, v + 4, 5);
		GP142_circleXY(BLACK, h + eye - 8, v + 4, 2);
		GP142_circleXY(BLACK, h + eye + 8, v + 4, 2);
	}
	else
	{
		GP142_circleXY(color + 5, h - 8, v + 4, 5);  /* eyes */
		GP142_circleXY(color + 5, h + 8, v + 4, 5);
	}

	smile = (rand() % 4);
	if (smile > 2)
	{
		GP142_ovalXY  (WHITE, h - 14, v - 14, h + 14,  v - 14, 10);
		GP142_lineXY  (BLACK, h - 19,v - 14, h + 19, v - 14, 1);  /* horizontal tooth line */
		GP142_lineXY  (BLACK, h,     v - 19, h,      v - 8,  1);  /* center of teeth, vertical */
		GP142_lineXY  (BLACK, h - 7, v - 18, h - 7,  v - 9,  1);  /* 1st left line from the center, vertical */
		GP142_lineXY  (BLACK, h - 13,v - 17, h - 13, v - 10,  1);  /* 2nd left line from the center, vertical */
		GP142_lineXY  (BLACK, h + 7, v - 18, h + 7,  v - 9,  1);  /* 1st right line from the center, vertical */
		GP142_lineXY  (BLACK, h + 13 ,v - 18, h + 13, v - 10,  1);  /* 2nd right line from the center, vertical */
	}
	else 
		GP142_ovalXY  (RED, h - 14, v - 14, h + 14,  v - 14, 10);
}


/* Draw a small little human figure.  Draw a cirlce and cut out the body parts 
   using triangles. */

void DrawBody(int x1, int y1, int color, int background_color)
{
	
	int x = x1; 
	int y = y1 + rand() % 9;
	int blink = rand() % 10;

	GP142_circleXY(color + 16, x     , y - 15,  25);   /* body */
	GP142_circleXY(color + 7, x     , y - 13,  16);
	/* these following triangle "cut-out" the body.  */
	GP142_triangleXY(background_color, x    , y - 20, x - 15, y - 45, x + 15, y - 45, FILL);
	GP142_triangleXY(background_color, x + 7, y - 10, x + 30, y - 10, x + 20, y - 30, FILL);
	GP142_triangleXY(background_color, x - 7, y - 10, x - 30, y - 10, x - 20, y - 30, FILL);
	GP142_triangleXY(background_color, x + 20,     y, x - 20,      y,      x, y + 20, FILL);
	/* face and eyes */
	GP142_circleXY(color + 16, x    , y + 15,  15);
	if (blink < 8)
	{
		GP142_circleXY(BLACK, x + 5, y + 15,  2);
		GP142_circleXY(BLACK, x - 5, y + 15,  2);
	}
	else 
	{
		GP142_circleXY(color + 16, x + 5, y + 15,  2);
		GP142_circleXY(color + 16, x - 5, y + 15,  2);
	}
}




void DrawChecker(int *color)
{
	int row;        
	int col;         
	int offset;      
	int top  =  GP142_YMAX;	
	int left = -GP142_XMAX;   
	int right=  GP142_XMAX;  
	int bottom=-GP142_YMAX;
	int square_size = 50;     /* also equal to the offset */
	int checker_color;

	checker_color = ((5) + *color);

	offset = square_size;      /* initializes the offset that is used in loop */                                                              

	/* this loop draws the rows of squares   */
	for(row = bottom;
		row < top;
		row = row + square_size)
	{
		if(offset == square_size)  /* previous row had an offset   */
			offset = 0;                    
		else  /* the last row was not offset */
			offset = square_size; 
		
	/* this loop draws the columns of squares  */

		for(col = left; col < right; col = col + (2 * square_size))
				GP142_rectangleXY(LT_GRAY, col + offset, row, col + offset + square_size, 
							  row + square_size, FILL);
		
	}
}


/* Draw border around card */  


void DrawBorder(void)
{
	GP142_rectangleXY (BLACK, PAGE_LLX - 5, PAGE_LLY - 5,
		PAGE_LLX+ PAGE_WIDTH + 5, PAGE_LLY+ PAGE_HEIGHT + 5, FILL);
}


/* put name and title on screen with card */

void DrawTitle(void)
{
	GP142_printfXY(BLACK, PAGE_LLX - 10, GP142_YMAX - 47, 40,
		           "Create - A - Card");
	GP142_printfXY(RED,   PAGE_LLX -  8, GP142_YMAX - 45, 40,
		           "Create - A - Card");
	GP142_printfXY(RED, -GP142_XMAX +  9, -GP142_YMAX + 39, 16,
		           "Valentine Card Design");
	GP142_printfXY(FOREST_GREEN, -GP142_XMAX + 10, -GP142_YMAX + 40, 16,
		           "Valentine Card Design");
	GP142_printfXY(RED, -GP142_XMAX +  9, -GP142_YMAX + 24, 15, 
		           "By: Doug Thompson");
	GP142_printfXY(FOREST_GREEN, -GP142_XMAX + 10, -GP142_YMAX + 25, 15, 
		           "By: Doug Thompson");
    GP142_printfXY(RED, -GP142_XMAX +  9, -GP142_YMAX +  9, 15,
		           "CSE/ENG 142, Winter 1999");
    GP142_printfXY(FOREST_GREEN , -GP142_XMAX + 10, -GP142_YMAX + 10, 15,
		           "CSE/ENG 142, Winter 1999");
                                                                                

}

/* and that's all folks */